import { useState, useEffect } from "react";
import Taro, { useDidShow, useReady } from "@tarojs/taro";
import withLayout from "@/layout";
import { Image } from "@tarojs/components";
import { queryLiveDetail } from "@/services/item";
import useParams from "@/utils/hooks/useParams";
import useShare from "@/utils/hooks/useShare";
import { getImgURL } from "@/utils/image";
import "@/assets/css/iconfont.css";
import "./index.scss";

export default withLayout((props) => {
  const { router, shareContent, trackData, person, page } = props;
  const { id } = router.params;

  const [data,setData] = useState({})
  
  // 本页面分享或者海报参数
  const paramsRef = useParams({
    id,
    buildingId: data.buildingId,
    person,
    from: `${page.type}_share`,
  });
  const fullTrackData = { ...trackData, buildingId: data.buildingId };
  
  useShare(
    {
      title: shareContent.shareContentTitle || data?.name,
      path: `${router.path}?${paramsRef.current}`,
      image: shareContent.shareContentImg || getImgURL(data?.vide_img),
    },
    fullTrackData
  );

  const getData = () => {
    queryLiveDetail(id).then(res=>{
        setData(res)
    })
  };

  useEffect(() => {
    if (id) {
      getData(id);
    }
  }, [id]);
//   
  return <view className="liveDetail">
       {data.liveActivityId&&<><Image mode='aspectFill' src={getImgURL(data.detailTypeImg)} className='liveImg'></Image>
       <view className='liveDetail-menu'>
           <view onClick={()=>{Taro.navigateTo({ url: `/pages/index/buildingDetail/index?id=${data.buildingId}` })}}><text className="iconfont icon-fenxiang"></text><text>查看楼盘</text></view>
           <view><text className="iconfont icon-camera"></text><text>观看直播</text></view>
           <button openType="share"><text className="iconfont icon-fenxiang"></text><text>分享好友</text></button>
       </view></>}
  </view>;
});
